==> jc-1.4.0.tar.gz: java/util/Timer__24Scheduler.h <==
// final class java.util.Timer$Scheduler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b51246f4f13b93cb java_util_Timer__24Scheduler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Timer__24Scheduler_H_
#define _JC_java_util_Timer__24Scheduler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Timer__24TaskQueue$object;

// Typedefs
typedef struct _jc_java_util_Timer__24Scheduler$sub_refs	_jc_java_util_Timer__24Scheduler$sub_refs;
typedef struct _jc_java_util_Timer__24Scheduler$sub_nonrefs	_jc_java_util_Timer__24Scheduler$sub_nonrefs;
typedef struct _jc_java_util_Timer__24Scheduler$refs	_jc_java_util_Timer__24Scheduler$refs;
typedef struct _jc_java_util_Timer__24Scheduler$nonrefs	_jc_java_util_Timer__24Scheduler$nonrefs;
typedef struct _jc_java_util_Timer__24Scheduler$object	_jc_java_util_Timer__24Scheduler$object;

typedef const struct _jc_java_util_Timer__24Scheduler$vmethods	_jc_java_util_Timer__24Scheduler$vmethods;
typedef const struct _jc_java_util_Timer__24Scheduler$vtable	_jc_java_util_Timer__24Scheduler$vtable;
typedef const struct _jc_java_util_Timer__24Scheduler$vtype	_jc_java_util_Timer__24Scheduler$vtype;

// Constructors
extern void _jc_java_util_Timer__24Scheduler$method$_init$93dd833eb8a9554a(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *, struct _jc_java_util_Timer__24TaskQueue$object *);

// Virtual methods
extern void _jc_java_util_Timer__24Scheduler$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Timer__24Scheduler$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_util_Timer__24Scheduler$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *);
};

// Vtable
struct _jc_java_util_Timer__24Scheduler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Timer__24Scheduler$vmethods	java_util_Timer__24Scheduler;
};

// Vtype
struct _jc_java_util_Timer__24Scheduler$vtype {
	_jc_type			type;
	_jc_java_util_Timer__24Scheduler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Timer__24Scheduler$sub_refs {
	struct _jc_java_util_Timer__24TaskQueue$object	*queue;
};

// Reference instance fields (object)
struct _jc_java_util_Timer__24Scheduler$refs {
    _jc_java_util_Timer__24Scheduler$sub_refs	java_util_Timer__24Scheduler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Timer__24Scheduler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Timer__24Scheduler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Timer__24Scheduler$sub_nonrefs	java_util_Timer__24Scheduler;
};

// Object instance structure
struct _jc_java_util_Timer__24Scheduler$object {
	_jc_java_util_Timer__24Scheduler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Timer__24Scheduler$vtype	*vtype;
	_jc_java_util_Timer__24Scheduler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Timer__24Scheduler$vtype _jc_java_util_Timer__24Scheduler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Timer__24Scheduler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Timer__24Scheduler$class_object;

#endif	/* _JC_java_util_Timer__24Scheduler_H_ */

==> jc-1.4.6.tar.gz: java/util/Timer__24Scheduler.h <==
// final class java.util.Timer$Scheduler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b51246f4f13b93cb java_util_Timer__24Scheduler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Timer__24Scheduler_H_
#define _JC_java_util_Timer__24Scheduler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Timer__24TaskQueue$object;

// Typedefs
typedef struct _jc_java_util_Timer__24Scheduler$sub_refs	_jc_java_util_Timer__24Scheduler$sub_refs;
typedef struct _jc_java_util_Timer__24Scheduler$sub_nonrefs	_jc_java_util_Timer__24Scheduler$sub_nonrefs;
typedef struct _jc_java_util_Timer__24Scheduler$refs	_jc_java_util_Timer__24Scheduler$refs;
typedef struct _jc_java_util_Timer__24Scheduler$nonrefs	_jc_java_util_Timer__24Scheduler$nonrefs;
typedef struct _jc_java_util_Timer__24Scheduler$object	_jc_java_util_Timer__24Scheduler$object;

typedef const struct _jc_java_util_Timer__24Scheduler$vmethods	_jc_java_util_Timer__24Scheduler$vmethods;
typedef const struct _jc_java_util_Timer__24Scheduler$vtable	_jc_java_util_Timer__24Scheduler$vtable;
typedef const struct _jc_java_util_Timer__24Scheduler$vtype	_jc_java_util_Timer__24Scheduler$vtype;

// Constructors
extern void _jc_java_util_Timer__24Scheduler$method$_init$93dd833eb8a9554a(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *, struct _jc_java_util_Timer__24TaskQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_Timer__24Scheduler$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Timer__24Scheduler$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_util_Timer__24Scheduler$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_util_Timer__24Scheduler$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Timer__24Scheduler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Timer__24Scheduler$vmethods	java_util_Timer__24Scheduler;
};

// Vtype
struct _jc_java_util_Timer__24Scheduler$vtype {
	_jc_type			type;
	_jc_java_util_Timer__24Scheduler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Timer__24Scheduler$sub_refs {
	struct _jc_java_util_Timer__24TaskQueue$object	*queue;
};

// Reference instance fields (object)
struct _jc_java_util_Timer__24Scheduler$refs {
    _jc_java_util_Timer__24Scheduler$sub_refs	java_util_Timer__24Scheduler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Timer__24Scheduler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Timer__24Scheduler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Timer__24Scheduler$sub_nonrefs	java_util_Timer__24Scheduler;
};

// Object instance structure
struct _jc_java_util_Timer__24Scheduler$object {
	_jc_java_util_Timer__24Scheduler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Timer__24Scheduler$vtype	*vtype;
	_jc_java_util_Timer__24Scheduler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Timer__24Scheduler$vtype _jc_java_util_Timer__24Scheduler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Timer__24Scheduler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Timer__24Scheduler$class_object;

#endif	/* _JC_java_util_Timer__24Scheduler_H_ */
